Get rid of C++/C99-style comments.
[metze/wireshark/wip.git] / merge.h
diff --git a/merge.h b/merge.h
index 887e1b866cec44969568ea492d42f996a1549024..a9a36f2c9308d416ae2b550dd6e9d6397e32ee25 100644 (file)
--- a/merge.h
+++ b/merge.h
@@ -3,8 +3,8 @@
  *
  * $Id$
  *
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@ethereal.com>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
  * This program is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __MERGE_H__
@@ -42,9 +42,12 @@ typedef enum {
 typedef struct merge_in_file_s {
   const char     *filename;
   wtap           *wth;
-  long            data_offset;
+  gint64          data_offset;
   in_file_state_e state;
-  long            size;                /* file size */
+  guint32         packet_num;    /* current packet number */
+  gint64          size;                      /* file size */
+  guint32         interface_id;   /* identifier of the interface. 
+                                                                  * Used for fake interfaces when writing WTAP_ENCAP_PER_PACKET */
 } merge_in_file_t;
 
 /** Open a number of input files to merge.
@@ -95,10 +98,10 @@ merge_max_snapshot_length(int in_file_count, merge_in_file_t in_files[]);
  * @param in_files input file array
  * @param err wiretap error, if failed
  * @param err_info wiretap error string, if failed
* @return pointer to wtap for file from which that packet came, or NULL on
* error or EOF
  */
-extern wtap *
+extern merge_in_file_t *
 merge_read_packet(int in_file_count, merge_in_file_t in_files[], int *err,
                   gchar **err_info);
 
@@ -110,10 +113,10 @@ merge_read_packet(int in_file_count, merge_in_file_t in_files[], int *err,
  * @param in_files input file array
  * @param err wiretap error, if failed
  * @param err_info wiretap error string, if failed
* @return pointer to wtap for file from which that packet came, or NULL on
* error or EOF
  */
-extern wtap *
+extern merge_in_file_t *
 merge_append_read_packet(int in_file_count, merge_in_file_t in_files[],
                          int *err, gchar **err_info);
@@ -95,10 +98,10 @@ merge_max_snapshot_length(int in_file_count, merge_in_file_t in_files[]);
  * @param err wiretap error, if failed
  * @param err_info wiretap error string, if failed
- * @return pointer to wtap for file from which that packet came, or NULL on
- * error or EOF
+ * @return pointer to merge_in_file_t for file from which that packet
+ * came, or NULL on error or EOF
  */
@@ -110,10 +113,10 @@ merge_read_packet(int in_file_count, merge_in_file_t in_files[], int *err,
  * @param err wiretap error, if failed
  * @param err_info wiretap error string, if failed
- * @return pointer to wtap for file from which that packet came, or NULL on
- * error or EOF
+ * @return pointer to merge_in_file_t for file from which that packet
+ * came, or NULL on error or EOF
  */